CopiedSequenceItem

Struct CopiedSequenceItem 

pub struct CopiedSequenceItem {
    pub source_reference: Option<ReferenceSpec>,
    pub source_coordinate_system: Option<CoordinateSystem>,
    pub source_location: Interval<NucleotideCoordinate>,
    pub is_inverted: bool,
}
Sequence copied from the same or another reference.

Examples

use tinyhgvs::{NucleotideEdit, NucleotideSequenceItem, VariantDescription, parse_hgvs};

let variant = parse_hgvs("LRG_199t1:c.419_420ins[T;450_470;AGGG]").unwrap();

match variant.description {
    VariantDescription::Nucleotide(description) => {
        let NucleotideEdit::Insertion { items } = description.edit else {
            unreachable!("expected insertion");
        };
        let NucleotideSequenceItem::Copied(item) = &items[1] else {
            unreachable!("expected copied sequence");
        };
        assert!(item.is_from_same_reference());
        assert_eq!(item.source_location.start.coordinate, 450);
        assert_eq!(item.source_location.end.as_ref().unwrap().coordinate, 470);
    }
    VariantDescription::Protein(_) => unreachable!("expected nucleotide variant"),
}

Fields

source_reference: Option<ReferenceSpec>

None when the copied segment comes from the same reference source as written in the reference metadata.

source_coordinate_system: Option<CoordinateSystem>

None when the same coordinate system is used as written in the reference metadata.

source_location: Interval<NucleotideCoordinate>

Interval on the source reference from which sequence is copied.

is_inverted: bool

Whether the copied sequence is inverted.

Implementations

Source

impl CopiedSequenceItem

pub fn is_from_same_reference(&self) -> bool

Returns true when the copied sequence comes from the outer reference.